@@ -238,7 +238,7 @@ def Mean_KLD (P,Q):
         prediction = Q[idx]
         kld = scipy.stats.entropy(ground_truth, prediction) # If 2nd param is not None, then compute the Kullback-Leibler divergence. S = sum(pk * log(pk / qk), axis=axis).
         klds.append(kld)
-    return np.mean(klds), klds
+    return np.mean(klds) # , klds
 
 CLF_METRICS = ['classification.ACC',
                'classification.Kappa',
